import * as react_jsx_runtime from 'react/jsx-runtime';
import * as React from 'react';
import { ReactNode } from 'react';
import { EVMSmartWallet, SolanaSmartWallet } from '@crossmint/wallets-sdk';
import { UIConfig } from '@crossmint/common-sdk-base';
import { PasskeySigner } from '../types/passkey.js';
import { GetOrCreateWalletProps } from '@crossmint/client-sdk-react-base';
import 'ox';

type ValidPasskeyPromptType = "create-wallet" | "transaction" | "not-supported" | "create-wallet-error" | "transaction-error";
type WalletContextFunctions = {
    getOrCreateWallet: (args: GetOrCreateWalletProps) => Promise<{
        startedCreation: boolean;
        reason?: string;
    }>;
    createPasskeySigner: (name: string, promptType?: ValidPasskeyPromptType) => Promise<PasskeySigner | null>;
    clearWallet: () => void;
    experimental_getOrCreateWalletWithRecoveryKey?: (args: {
        type: "solana-smart-wallet";
        email: string;
    }) => Promise<void>;
    passkeySigner?: PasskeySigner;
};
type WalletType = {
    "evm-smart-wallet": EVMSmartWallet;
    "solana-smart-wallet": SolanaSmartWallet;
};
type LoadedWalletState<T extends keyof WalletType> = {
    status: "loaded";
    wallet: WalletType[T];
    type: T;
    error?: undefined;
};
type WalletContext = ({
    status: "not-loaded" | "in-progress";
    wallet?: undefined;
    type?: undefined;
    error?: undefined;
} & WalletContextFunctions) | ({
    status: "loading-error";
    wallet?: undefined;
    type?: undefined;
    error: string;
} & WalletContextFunctions) | (LoadedWalletState<"evm-smart-wallet"> & WalletContextFunctions) | (LoadedWalletState<"solana-smart-wallet"> & WalletContextFunctions);
declare const WalletContext: React.Context<WalletContext>;
declare function CrossmintWalletProvider({ children, showPasskeyHelpers, appearance, experimental_enableRecoveryKeys, }: {
    children: ReactNode;
    showPasskeyHelpers?: boolean;
    appearance?: UIConfig;
    experimental_enableRecoveryKeys?: boolean;
}): react_jsx_runtime.JSX.Element;

export { CrossmintWalletProvider, WalletContext };
